==> wikitty-api-3.4-test-sources.jar: org/nuiton/wikitty/test/ProductDocumentationAbstract.java <==
package org.nuiton.wikitty.test;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.Date;
import java.util.LinkedHashSet;
import java.util.List;
import java.util.Set;
import org.nuiton.wikitty.WikittyUtil;
import org.nuiton.wikitty.entities.BusinessEntity;
import org.nuiton.wikitty.entities.BusinessEntityImpl;
import org.nuiton.wikitty.entities.Wikitty;
import org.nuiton.wikitty.entities.WikittyExtension;
import org.nuiton.wikitty.entities.WikittyTreeNode;
import org.nuiton.wikitty.entities.WikittyTreeNodeAbstract;
import org.nuiton.wikitty.entities.WikittyTreeNodeImpl;
import org.nuiton.wikitty.entities.WikittyUser;
import org.nuiton.wikitty.entities.WikittyUserAbstract;
import org.nuiton.wikitty.entities.WikittyUserImpl;

public abstract class ProductDocumentationAbstract extends BusinessEntityImpl implements ProductDocumentation {

    public static final List<WikittyExtension> extensions;

    public static final WikittyExtension extensionProductDocumentation;

    private static final long serialVersionUID = 3979264729337444707L;

    @Override
    public String getDocumentation() {
String value = ProductDocumentationHelper.getDocumentation(getWikitty());
return value;
}

    @Override
    public void setDocumentation(String documentation) {
String oldValue = getDocumentation();
ProductDocumentationHelper.setDocumentation(getWikitty(), documentation);
getPropertyChangeSupport().firePropertyChange(ProductDocumentation.FIELD_PRODUCTDOCUMENTATION_DOCUMENTATION, oldValue, getDocumentation());
}

    @Override
    public int getPrice() {
int value = ProductDocumentationHelper.getPrice(getWikitty());
return value;
}

    @Override
    public void setPrice(int price) {
int oldValue = getPrice();
ProductDocumentationHelper.setPrice(getWikitty(), price);
getPropertyChangeSupport().firePropertyChange(ProductDocumentation.FIELD_PRODUCTDOCUMENTATION_PRICE, oldValue, getPrice());
}

    public ProductDocumentationAbstract() {
        super();
}

    public ProductDocumentationAbstract(Wikitty wikitty) {
        super(wikitty);
}

    public ProductDocumentationAbstract(BusinessEntityImpl businessEntityImpl) {
        super(businessEntityImpl.getWikitty());
}

    @Override
    public Collection<WikittyExtension> getStaticExtensions() {
        return extensions;
}

    static {
    
        extensionProductDocumentation = new WikittyExtension(EXT_PRODUCTDOCUMENTATION,
                "1.0", // version
                WikittyUtil.tagValuesToMap(""), // tag/values
                (List)null,
                WikittyUtil.buildFieldMapExtension( // building field map
                                                                 "String documentation unique=\"true\"", 
                                             "Numeric price unique=\"true\""));

        // init extensions
        List<WikittyExtension> exts = new ArrayList<WikittyExtension>();

        exts.add(extensionProductDocumentation);
        extensions = Collections.unmodifiableList(exts);

    }

    /**
     * Return toString representation. Use tagValue 'toString' format, if exist, else standard toString is call
     * @return 
     */
    @Override
    public String toString() {
        return ProductDocumentationHelper.toString(getWikitty());
}

} //ProductDocumentationAbstract

==> wikitty-api-3.5-test-sources.jar: org/nuiton/wikitty/test/ProductDocumentationAbstract.java <==
package org.nuiton.wikitty.test;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.Date;
import java.util.LinkedHashSet;
import java.util.List;
import java.util.Set;
import org.nuiton.wikitty.WikittyUtil;
import org.nuiton.wikitty.entities.BusinessEntity;
import org.nuiton.wikitty.entities.BusinessEntityImpl;
import org.nuiton.wikitty.entities.Wikitty;
import org.nuiton.wikitty.entities.WikittyExtension;
import org.nuiton.wikitty.entities.WikittyTreeNode;
import org.nuiton.wikitty.entities.WikittyTreeNodeAbstract;
import org.nuiton.wikitty.entities.WikittyTreeNodeImpl;
import org.nuiton.wikitty.entities.WikittyUser;
import org.nuiton.wikitty.entities.WikittyUserAbstract;
import org.nuiton.wikitty.entities.WikittyUserImpl;

public abstract class ProductDocumentationAbstract extends BusinessEntityImpl implements ProductDocumentation {

    public static final List<WikittyExtension> extensions;

    public static final WikittyExtension extensionProductDocumentation;

    private static final long serialVersionUID = 3979264729337444707L;

    @Override
    public String getDocumentation() {
String value = ProductDocumentationHelper.getDocumentation(getWikitty());
return value;
}

    @Override
    public void setDocumentation(String documentation) {
String oldValue = getDocumentation();
ProductDocumentationHelper.setDocumentation(getWikitty(), documentation);
getPropertyChangeSupport().firePropertyChange(ProductDocumentation.FIELD_PRODUCTDOCUMENTATION_DOCUMENTATION, oldValue, getDocumentation());
}

    @Override
    public int getPrice() {
int value = ProductDocumentationHelper.getPrice(getWikitty());
return value;
}

    @Override
    public void setPrice(int price) {
int oldValue = getPrice();
ProductDocumentationHelper.setPrice(getWikitty(), price);
getPropertyChangeSupport().firePropertyChange(ProductDocumentation.FIELD_PRODUCTDOCUMENTATION_PRICE, oldValue, getPrice());
}

    public ProductDocumentationAbstract() {
        super();
}

    public ProductDocumentationAbstract(Wikitty wikitty) {
        super(wikitty);
}

    public ProductDocumentationAbstract(BusinessEntityImpl businessEntityImpl) {
        super(businessEntityImpl.getWikitty());
}

    @Override
    public Collection<WikittyExtension> getStaticExtensions() {
        return extensions;
}

    static {
    
        extensionProductDocumentation = new WikittyExtension(EXT_PRODUCTDOCUMENTATION,
                "1.0", // version
                WikittyUtil.tagValuesToMap(""), // tag/values
                (List)null,
                WikittyUtil.buildFieldMapExtension( // building field map
                                                                 "String documentation", 
                                             "Numeric price"));

        // init extensions
        List<WikittyExtension> exts = new ArrayList<WikittyExtension>();

        exts.add(extensionProductDocumentation);
        extensions = Collections.unmodifiableList(exts);

    }

    /**
     * Return toString representation. Use tagValue 'toString' format, if exist, else standard toString is call
     * @return 
     */
    @Override
    public String toString() {
        return ProductDocumentationHelper.toString(getWikitty());
}

} //ProductDocumentationAbstract
